from setuptools import setup

setup(
    name='jdsgreeter',
    version='0.0.1',
    description='a pip-installable package example',
    license='MIT',
    packages=['jdsgreeter'],
    author='John D Sheehan',
    author_email='john.d.sheehan@gmail.com',
    keywords=['example'],
    url='https://github.com/johndsheehan/greeter'
)
